@@ -44,7 +44,7 @@ AmericanSoccerAnalysis <- R6::R6Class("AmericanSoccerAnalysis",
             self$base_url <- glue::glue("https://app.americansocceranalysis.com/api/{self$API_VERSION}")
             self$httr_configs <- list(...)
 
-            if (!rlang::is_interactive() && !isTRUE(as.logical(Sys.getenv("NOT_CRAN", "false")))) {
+            if (isFALSE(as.logical(Sys.getenv("NOT_CRAN", "false")))) {
                 self$latest_update_timestamp <- .get_latest_update_timestamp(self)
                 .initialize_entities(self, verbose = TRUE)
             }
