@@ -1,5 +1,9 @@
 test_that("Filtering players works properly", {
 
+    # TODO: Move all these tests into the API codebase and mock what's below
+    skip_on_cran()
+    skip_on_ci()
+
     # No filters ---------------------------------------------------------
     .obj <- asa_client$get_players() %>% nrow()
     .exp <- asa_client$players %>% nrow()
@@ -103,6 +107,10 @@ test_that("Filtering players works properly", {
 
 test_that("Filtering teams works properly", {
 
+    # TODO: Move all these tests into the API codebase and mock what's below
+    skip_on_cran()
+    skip_on_ci()
+
     # No filters ---------------------------------------------------------
     .obj <- asa_client$get_teams() %>% nrow()
     .exp <- asa_client$teams %>% nrow()
@@ -210,6 +218,10 @@ test_that("Filtering teams works properly", {
 
 test_that("Filtering stadia works properly", {
 
+    # TODO: Move all these tests into the API codebase and mock what's below
+    skip_on_cran()
+    skip_on_ci()
+
     # No filters ---------------------------------------------------------
     .obj <- asa_client$get_stadia() %>% nrow()
     .exp <- asa_client$stadia %>% nrow()
@@ -317,6 +329,10 @@ test_that("Filtering stadia works properly", {
 
 test_that("Filtering managers works properly", {
 
+    # TODO: Move all these tests into the API codebase and mock what's below
+    skip_on_cran()
+    skip_on_ci()
+
     # No filters ---------------------------------------------------------
     .obj <- asa_client$get_managers() %>% nrow()
     .exp <- asa_client$managers %>% nrow()
@@ -424,6 +440,10 @@ test_that("Filtering managers works properly", {
 
 test_that("Filtering referees works properly", {
 
+    # TODO: Move all these tests into the API codebase and mock what's below
+    skip_on_cran()
+    skip_on_ci()
+
     # No filters ---------------------------------------------------------
     .obj <- asa_client$get_referees() %>% nrow()
     .exp <- asa_client$referees %>% nrow()
@@ -531,6 +551,10 @@ test_that("Filtering referees works properly", {
 
 test_that("Querying games works properly", {
 
+    # TODO: Move all these tests into the API codebase and mock what's below
+    skip_on_cran()
+    skip_on_ci()
+
     # No filters ---------------------------------------------------------
     .obj <- asa_client$get_games() %>% nrow()
     .exp <- asa_client$get_games(leagues = asa_client$LEAGUES) %>% nrow()
